@@ -1,32 +1,23 @@
-#
-# BioPerl module for Bio::DB::EUtilities
-#
-# Please direct questions and support issues to <bioperl-l@bioperl.org>
-#
-# Cared for by Chris Fields <cjfields at bioperl dot org>
-#
-# Copyright Chris Fields
-#
-# You may distribute this module under the same terms as perl itself
-#
-# POD documentation - main docs before the code
-#
-# EUtil-based extension of GenericWebDBI interface
-
-
-# Let the code begin...
-
 package Bio::DB::EUtilities;
 BEGIN {
-  $Bio::DB::EUtilities::AUTHORITY = 'cpan:CJFIELDS';
+  $Bio::DB::EUtilities::AUTHORITY = 'cpan:BIOPERLML';
 }
-our $VERSION = '1.72'; # VERSION
-
+{
+  $Bio::DB::EUtilities::VERSION = '1.73';
+}
+use utf8;
 use strict;
+use warnings;
+use base qw(Bio::DB::GenericWebAgent);
 use Bio::Tools::EUtilities::EUtilParameters;
 use Bio::Tools::EUtilities;
 
-use base qw(Bio::DB::GenericWebAgent);
+# ABSTRACT: Webagent which interacts with and retrieves data from NCBI's eUtils.
+# AUTHOR:   Chris Fields <cjfields@bioperl.org>
+# OWNER:    2006-2013 Chris Fields
+# LICENSE:  Perl_5
+
+
 
 sub new {
     my($class,@args) = @_;
@@ -397,6 +388,7 @@ sub callback {
 
 1;
 
+__END__
 
 =pod
 
@@ -404,7 +396,11 @@ sub callback {
 
 =head1 NAME
 
-Bio::DB::EUtilities
+Bio::DB::EUtilities - Webagent which interacts with and retrieves data from NCBI's eUtils.
+
+=head1 VERSION
+
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -494,10 +490,9 @@ BioPerl-Run, utilizes the SOAP-based interface for eUtils.
 A full explanation of the eUtils interfaces are not possible within this short
 module; please see the BioPerl wiki HOWTO for more details.
 
-=head1 NAME
+=head1 METHODS
 
-Bio::DB::EUtilities - webagent which interacts with and retrieves data from
-NCBI's eUtils
+=head2
 
 =head1 TODO
 
@@ -526,11 +521,6 @@ between calls.
 
 Setting history is a bit inconsistent, so maybe use a common alias for this?
 
-=item * Splitting out of core
-
-This could easily belong in its own distribution, the only tie to BioPerl is the
-use of Bio::Root::Root.
-
 =item * Moosify?
 
 Not necessary, but it might make things easier and more maintainable in the long
@@ -538,48 +528,6 @@ run.
 
 =back
 
-=head1 FEEDBACK
-
-=head2 Mailing Lists
-
-User feedback is an integral part of the
-evolution of this and other Bioperl modules. Send
-your comments and suggestions preferably to one
-of the Bioperl mailing lists. Your participation
-is much appreciated.
-
-  bioperl-l@lists.open-bio.org               - General discussion
-  http://www.bioperl.org/wiki/Mailing_lists  - About the mailing lists
-
-=head2 Support
-
-Please direct usage questions or support issues to the mailing list:
-
-I<bioperl-l@bioperl.org>
-
-rather than to the module maintainer directly. Many experienced and
-reponsive experts will be able look at the problem and quickly
-address it. Please include a thorough description of the problem
-with code and data examples if at all possible.
-
-=head2 Reporting Bugs
-
-Report bugs to the Bioperl bug tracking system to
-help us keep track the bugs and their resolution.
-Bug reports can be submitted via the web.
-
-  https://redmine.open-bio.org/projects/bioperl/
-
-=head1 AUTHOR
-
-Email cjfields at bioperl dot org
-
-=head1 APPENDIX
-
-The rest of the documentation details each of the
-object methods. Internal methods are usually
-preceded with a _
-
 =head1 Bio::DB::GenericWebAgent methods
 
 =head1 GenericWebDBI methods
@@ -1271,18 +1219,43 @@ ones deemed absolutely necessary).  All others are available by calling
             'reset' - string, resets the iterator.
             returns upon any other args
 
+=head1 FEEDBACK
+
+=head2 Mailing lists
+
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to
+the Bioperl mailing list.  Your participation is much appreciated.
+
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support
+
+Please direct usage questions or support issues to the mailing list:
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
+with code and data examples if at all possible.
+
+=head2 Reporting bugs
+
+Report bugs to the Bioperl bug tracking system to help us keep track
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
+
+  https://redmine.open-bio.org/projects/bioperl/
+
 =head1 AUTHOR
 
-cjfields <cjfields@bioperl.org>
+Chris Fields <cjfields@bioperl.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2011 by Chris Fields.
+This software is copyright (c) 2006-2013 by Chris Fields.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This software is available under the same terms as the perl 5 programming language system itself.
 
 =cut
-
-
-__END__
