@@ -1,33 +1,24 @@
-#
-# BioPerl module for Bio::Tools::EUtilities::EUtilParameters
-#
-# Please direct questions and support issues to <bioperl-l@bioperl.org>
-#
-# Cared for by Chris Fields <cjfields at bioperl dot org>
-#
-# Copyright Chris Fields
-#
-# You may distribute this module under the same terms as perl itself
-#
-# POD documentation - main docs before the code
-
-
-# Let the code begin...
-
 package Bio::Tools::EUtilities::EUtilParameters;
 BEGIN {
-  $Bio::Tools::EUtilities::EUtilParameters::AUTHORITY = 'cpan:CJFIELDS';
+  $Bio::Tools::EUtilities::EUtilParameters::AUTHORITY = 'cpan:BIOPERLML';
 }
-our $VERSION = '1.72'; # VERSION
-
+{
+  $Bio::Tools::EUtilities::EUtilParameters::VERSION = '1.73';
+}
+use utf8;
 use strict;
 use warnings;
-
 use base qw(Bio::Root::Root Bio::ParameterBaseI);
 use URI;
 use HTTP::Request;
 use Bio::Root::IO;
 
+# ABSTRACT: Manipulation of NCBI eutil-based parameters for remote database requests.
+# AUTHOR:   Chris Fields <cjfields@bioperl.org>
+# OWNER:    2006-2013 Chris Fields
+# LICENSE:  Perl_5
+
+
 # eutils only has one hostbase URL
 
 # mode : GET or POST (HTTP::Request)
@@ -61,7 +52,7 @@ my %MODE = (
         'mode'     => ['GET','POST'],
         'location' => 'esummary.fcgi',
         'params'   => [qw(db retmode id retmax retstart rettype tool email
-                       WebEnv query_key)],
+                       version WebEnv query_key)],
                    },
     'elink'     => {
         'mode'     => ['GET','POST'],
@@ -419,13 +410,18 @@ sub _io {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Bio::Tools::EUtilities::EUtilParameters
+Bio::Tools::EUtilities::EUtilParameters - Manipulation of NCBI eutil-based parameters for remote database requests.
+
+=head1 VERSION
+
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -469,53 +465,6 @@ set_parameters() or reset_parameters():
 At this point minimal checking is done for potential errors in parameter
 passing, though these should be easily added in the future when necessary.
 
-=head1 NAME
-
-Bio::Tools::EUtilities::EUtilParameters - Manipulation of NCBI eutil-based
-parameters for remote database requests.
-
-=head1 FEEDBACK
-
-=head2 Mailing Lists
-
-User feedback is an integral part of the
-evolution of this and other Bioperl modules. Send
-your comments and suggestions preferably to one
-of the Bioperl mailing lists. Your participation
-is much appreciated.
-
-  bioperl-l@lists.open-bio.org               - General discussion
-  http://www.bioperl.org/wiki/Mailing_lists  - About the mailing lists
-
-=head2 Support
-
-Please direct usage questions or support issues to the mailing list:
-
-I<bioperl-l@bioperl.org>
-
-rather than to the module maintainer directly. Many experienced and
-reponsive experts will be able look at the problem and quickly
-address it. Please include a thorough description of the problem
-with code and data examples if at all possible.
-
-=head2 Reporting Bugs
-
-Report bugs to the Bioperl bug tracking system to
-help us keep track the bugs and their resolution.
-Bug reports can be submitted via the web.
-
-  https://redmine.open-bio.org/projects/bioperl/
-
-=head1 AUTHOR
-
-Email cjfields at bioperl dot org
-
-=head1 APPENDIX
-
-The rest of the documentation details each of the
-object methods. Internal methods are usually
-preceded with a _
-
 =head1 Bio::ParameterBaseI implemented methods
 
 =head2 set_parameters
@@ -713,16 +662,43 @@ preceded with a _
  Returns : none
  Args    : none
 
+=head1 FEEDBACK
+
+=head2 Mailing lists
+
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to
+the Bioperl mailing list.  Your participation is much appreciated.
+
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support
+
+Please direct usage questions or support issues to the mailing list:
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
+with code and data examples if at all possible.
+
+=head2 Reporting bugs
+
+Report bugs to the Bioperl bug tracking system to help us keep track
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
+
+  https://redmine.open-bio.org/projects/bioperl/
+
 =head1 AUTHOR
 
-cjfields <cjfields@bioperl.org>
+Chris Fields <cjfields@bioperl.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2011 by Chris Fields.
+This software is copyright (c) 2006-2013 by Chris Fields.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This software is available under the same terms as the perl 5 programming language system itself.
 
 =cut
-
