@@ -1,33 +1,22 @@
-#
-# BioPerl module for Bio::Tools::EUtilities::History
-#
-# Please direct questions and support issues to <bioperl-l@bioperl.org>
-#
-# Cared for by Chris Fields
-#
-# Copyright Chris Fields
-#
-# You may distribute this module under the same terms as perl itself
-#
-# POD documentation - main docs before the code
-#
-# Part of the EUtilities BioPerl package
-
-
-
-# Let the code begin...
-
 package Bio::Tools::EUtilities::History;
 BEGIN {
-  $Bio::Tools::EUtilities::History::AUTHORITY = 'cpan:CJFIELDS';
+  $Bio::Tools::EUtilities::History::AUTHORITY = 'cpan:BIOPERLML';
 }
-our $VERSION = '1.72'; # VERSION
-
+{
+  $Bio::Tools::EUtilities::History::VERSION = '1.73';
+}
+use utf8;
 use strict;
 use warnings;
-
 use base qw(Bio::Root::Root Bio::Tools::EUtilities::HistoryI);
 
+# ABSTRACT: Lightweight implementation of HistoryI interface (not bound to filehandles, extraneous methods, etc).
+# AUTHOR:   Chris Fields <cjfields@bioperl.org>
+# OWNER:    2006-2013 Chris Fields
+# LICENSE:  Perl_5
+
+
+
 sub new {
     my ($class, @args) = @_;
     my $self = $class->SUPER::new(@args);
@@ -68,13 +57,18 @@ sub to_string {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Bio::Tools::EUtilities::History
+Bio::Tools::EUtilities::History - Lightweight implementation of HistoryI interface (not bound to filehandles, extraneous methods, etc).
+
+=head1 VERSION
+
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -105,49 +99,6 @@ This class is the simplest implementation and merely holds data for future
 queries from any HistoryI. See also Bio::Tools::EUtilities::Query (esearch) and
 Bio::Tools::EUtilities::LinkSet (elink), which also implement HistoryI.
 
-=head1 NAME
-
-Bio::Tools::EUtilities::History - lightweight implementation of HistoryI
-interface (not bound to filehandles, extraneous methods, etc).
-
-=head1 FEEDBACK
-
-=head2 Mailing Lists
-
-User feedback is an integral part of the evolution of this and other Bioperl
-modules. Send your comments and suggestions preferably to one of the Bioperl
-mailing lists. Your participation is much appreciated.
-
-  bioperl-l@lists.open-bio.org               - General discussion
-  http://www.bioperl.org/wiki/Mailing_lists  - About the mailing lists
-
-=head2 Support
-
-Please direct usage questions or support issues to the mailing list:
-
-I<bioperl-l@bioperl.org>
-
-rather than to the module maintainer directly. Many experienced and
-reponsive experts will be able look at the problem and quickly
-address it. Please include a thorough description of the problem
-with code and data examples if at all possible.
-
-=head2 Reporting Bugs
-
-Report bugs to the Bioperl bug tracking system to help us keep track the bugs
-and their resolution. Bug reports can be submitted via the web.
-
-  https://redmine.open-bio.org/projects/bioperl/
-
-=head1 AUTHOR
-
-Email cjfields at bioperl dot org
-
-=head1 APPENDIX
-
-The rest of the documentation details each of the object methods. Internal
-methods are usually preceded with a _
-
 =head2 history
 
  Title    : history
@@ -182,16 +133,43 @@ methods are usually preceded with a _
  Args     : (optional) simple data for text formatting
  Note     : Used generally for debugging and for the print_* methods
 
+=head1 FEEDBACK
+
+=head2 Mailing lists
+
+User feedback is an integral part of the evolution of this and other
+Bioperl modules. Send your comments and suggestions preferably to
+the Bioperl mailing list.  Your participation is much appreciated.
+
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support
+
+Please direct usage questions or support issues to the mailing list:
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
+with code and data examples if at all possible.
+
+=head2 Reporting bugs
+
+Report bugs to the Bioperl bug tracking system to help us keep track
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
+
+  https://redmine.open-bio.org/projects/bioperl/
+
 =head1 AUTHOR
 
-cjfields <cjfields@bioperl.org>
+Chris Fields <cjfields@bioperl.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2011 by Chris Fields.
+This software is copyright (c) 2006-2013 by Chris Fields.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This software is available under the same terms as the perl 5 programming language system itself.
 
 =cut
-
